/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Lesser General Public License as        *
 *   published by the Free Software Foundation;                            * 
 *                                                                         *
 ***************************************************************************/

/**
 * @file bidiParser.h
 * @brief Type definitions for Parser object.
 * @date $Date: 2004/10/22 08:32:53 $
 * @version $Revision: 1.1.1.1 $
   copyright            : (C) 2004 by Turbolinux,Inc.
*/

#ifndef BIDI_PARSER_H
#define BIDI_PARSER_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <libxml/xmlreader.h>
#include <bidiEntry.h>

#ifdef __cplusplus
extern "C" {
#endif

#if (LIBXML2_MAJOR_VERSION == 2) && (LIBXML2_MINOR_VERSION == 5) && (LIBXML2_MICRO_VERSION < 9)
  typedef enum {
    XML_READER_TYPE_NONE = 0,
    XML_READER_TYPE_ELEMENT = 1,
    XML_READER_TYPE_ATTRIBUTE = 2,
    XML_READER_TYPE_TEXT = 3,
    XML_READER_TYPE_CDATA = 4,
    XML_READER_TYPE_ENTITY_REFERENCE = 5,
    XML_READER_TYPE_ENTITY = 6,
    XML_READER_TYPE_PROCESSING_INSTRUCTION = 7,
    XML_READER_TYPE_COMMENT = 8,
    XML_READER_TYPE_DOCUMENT = 9,
    XML_READER_TYPE_DOCUMENT_TYPE = 10,
    XML_READER_TYPE_DOCUMENT_FRAGMENT = 11,
    XML_READER_TYPE_NOTATION = 12,
    XML_READER_TYPE_WHITESPACE = 13,
    XML_READER_TYPE_SIGNIFICANT_WHITESPACE = 14,
    XML_READER_TYPE_END_ELEMENT = 15,
    XML_READER_TYPE_END_ENTITY = 16,
    XML_READER_TYPE_XML_DECLARATION = 17
  } xmlReaderTypes;
#endif

  /**
   * @enum State.
   * Enumerate types used in Parser object.
   */
  typedef enum {
    STATE_START = 0,            
    STATE_PRINTER_MIB,

    STATE_LOC_TABLE,
    STATE_LOC_ENTRY,
    STATE_LOC_LANG,
    STATE_LOC_CHARSET,
    
    STATE_MRKSUP_TABLE,
    STATE_MRKSUP_ENTRY,
    STATE_MRKSUP_INDEX,
    STATE_MRKSUP_TYPE,
    STATE_MRKSUP_DESCRIPTION,
    STATE_MRKSUP_SUPPLYUNIT,
    STATE_MRKSUP_MAXCAPACITY,
    STATE_MRKSUP_LEVEL,
    
    STATE_ALT_TABLE,
    STATE_ALT_ENTRY,
    STATE_ALT_SEVERITYLEVEL,
    STATE_ALT_GROUP,
    STATE_ALT_GROUPINDEX,
    STATE_ALT_CODE,
    STATE_ALT_DESCRIPTION
  } State;

  /**
   * @struct Parser.
   * Structure for parser which parse printer status written in XML format.
   */
  typedef struct {
    xmlTextReaderPtr reader; /**< libxml2 text reader. */
    State state;             /**< In which entry is parser.*/
  } Parser;
  
  Parser * newParser(void);
  void deleteParsery(Parser *);
  int parseParser(Parser *, const char *);
  Entry *fetchEntryFromParser(Parser *);
  int parseParserFromFile(Parser*, const char*);
  int parseParserFromFd(Parser*, int);
  int parseParserFromBuff(Parser*, const char*, int);

#ifdef __cplusplus
}
#endif

#endif
